# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Invoice(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'invoice_id': 'str',
        'items': 'list[InvoiceItem]',
        'balance': 'str',
        'invoice_number': 'str',
        'object_id': 'str',
        'currency': 'str',
        'status': 'str',
        'type': 'str',
        'created_at': 'datetime',
        'target_at': 'datetime',
        'account': 'str',
        'object_type': 'int'
    }

    attribute_map = {
        'invoice_id': 'invoice_id',
        'items': 'items',
        'balance': 'balance',
        'invoice_number': 'invoice_number',
        'object_id': 'object_id',
        'currency': 'currency',
        'status': 'status',
        'type': 'type',
        'created_at': 'created_at',
        'target_at': 'target_at',
        'account': 'account',
        'object_type': 'object_type'
    }

    def __init__(self, invoice_id=None, items=None, balance=None, invoice_number=None, object_id=None, currency=None, status=None, type=None, created_at=None, target_at=None, account=None, object_type=None):  # noqa: E501
        """Invoice - a model defined in Swagger"""  # noqa: E501
        self._invoice_id = None
        self._items = None
        self._balance = None
        self._invoice_number = None
        self._object_id = None
        self._currency = None
        self._status = None
        self._type = None
        self._created_at = None
        self._target_at = None
        self._account = None
        self._object_type = None
        self.discriminator = None
        if invoice_id is not None:
            self.invoice_id = invoice_id
        if items is not None:
            self.items = items
        if balance is not None:
            self.balance = balance
        self.invoice_number = invoice_number
        if object_id is not None:
            self.object_id = object_id
        self.currency = currency
        self.status = status
        self.type = type
        if created_at is not None:
            self.created_at = created_at
        self.target_at = target_at
        self.account = account
        if object_type is not None:
            self.object_type = object_type

    @property
    def invoice_id(self):
        """Gets the invoice_id of this Invoice.  # noqa: E501


        :return: The invoice_id of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._invoice_id

    @invoice_id.setter
    def invoice_id(self, invoice_id):
        """Sets the invoice_id of this Invoice.


        :param invoice_id: The invoice_id of this Invoice.  # noqa: E501
        :type: str
        """

        self._invoice_id = invoice_id

    @property
    def items(self):
        """Gets the items of this Invoice.  # noqa: E501


        :return: The items of this Invoice.  # noqa: E501
        :rtype: list[InvoiceItem]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this Invoice.


        :param items: The items of this Invoice.  # noqa: E501
        :type: list[InvoiceItem]
        """

        self._items = items

    @property
    def balance(self):
        """Gets the balance of this Invoice.  # noqa: E501


        :return: The balance of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this Invoice.


        :param balance: The balance of this Invoice.  # noqa: E501
        :type: str
        """

        self._balance = balance

    @property
    def invoice_number(self):
        """Gets the invoice_number of this Invoice.  # noqa: E501


        :return: The invoice_number of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, invoice_number):
        """Sets the invoice_number of this Invoice.


        :param invoice_number: The invoice_number of this Invoice.  # noqa: E501
        :type: str
        """
        if invoice_number is None:
            raise ValueError("Invalid value for `invoice_number`, must not be `None`")  # noqa: E501

        self._invoice_number = invoice_number

    @property
    def object_id(self):
        """Gets the object_id of this Invoice.  # noqa: E501


        :return: The object_id of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this Invoice.


        :param object_id: The object_id of this Invoice.  # noqa: E501
        :type: str
        """

        self._object_id = object_id

    @property
    def currency(self):
        """Gets the currency of this Invoice.  # noqa: E501


        :return: The currency of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Invoice.


        :param currency: The currency of this Invoice.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501
        allowed_values = ["USD", "AED"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def status(self):
        """Gets the status of this Invoice.  # noqa: E501


        :return: The status of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Invoice.


        :param status: The status of this Invoice.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["DAFT", "COMMITTED", "VOID"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def type(self):
        """Gets the type of this Invoice.  # noqa: E501


        :return: The type of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Invoice.


        :param type: The type of this Invoice.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["FIXED", "REPAIR_ADJUSTMENT", "CREDIT_ADJUSTMENT", "ITEM_ADJUSTMENT", "TAX"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def created_at(self):
        """Gets the created_at of this Invoice.  # noqa: E501


        :return: The created_at of this Invoice.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Invoice.


        :param created_at: The created_at of this Invoice.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def target_at(self):
        """Gets the target_at of this Invoice.  # noqa: E501


        :return: The target_at of this Invoice.  # noqa: E501
        :rtype: datetime
        """
        return self._target_at

    @target_at.setter
    def target_at(self, target_at):
        """Sets the target_at of this Invoice.


        :param target_at: The target_at of this Invoice.  # noqa: E501
        :type: datetime
        """
        if target_at is None:
            raise ValueError("Invalid value for `target_at`, must not be `None`")  # noqa: E501

        self._target_at = target_at

    @property
    def account(self):
        """Gets the account of this Invoice.  # noqa: E501


        :return: The account of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this Invoice.


        :param account: The account of this Invoice.  # noqa: E501
        :type: str
        """
        if account is None:
            raise ValueError("Invalid value for `account`, must not be `None`")  # noqa: E501

        self._account = account

    @property
    def object_type(self):
        """Gets the object_type of this Invoice.  # noqa: E501


        :return: The object_type of this Invoice.  # noqa: E501
        :rtype: int
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """Sets the object_type of this Invoice.


        :param object_type: The object_type of this Invoice.  # noqa: E501
        :type: int
        """

        self._object_type = object_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Invoice, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Invoice):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PaymentMethod(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'payment_method_id': 'str',
        'plugin_properties': 'object',
        'plugin_details': 'str',
        'card_details': 'CardDetails',
        'external_key': 'str',
        'is_default': 'bool',
        'name': 'str',
        'plugin_name': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'billing_address': 'str'
    }

    attribute_map = {
        'payment_method_id': 'payment_method_id',
        'plugin_properties': 'plugin_properties',
        'plugin_details': 'plugin_details',
        'card_details': 'card_details',
        'external_key': 'external_key',
        'is_default': 'is_default',
        'name': 'name',
        'plugin_name': 'plugin_name',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'billing_address': 'billing_address'
    }

    def __init__(self, payment_method_id=None, plugin_properties=None, plugin_details=None, card_details=None, external_key=None, is_default=None, name=None, plugin_name=None, created_at=None, updated_at=None, billing_address=None):  # noqa: E501
        """PaymentMethod - a model defined in Swagger"""  # noqa: E501
        self._payment_method_id = None
        self._plugin_properties = None
        self._plugin_details = None
        self._card_details = None
        self._external_key = None
        self._is_default = None
        self._name = None
        self._plugin_name = None
        self._created_at = None
        self._updated_at = None
        self._billing_address = None
        self.discriminator = None
        if payment_method_id is not None:
            self.payment_method_id = payment_method_id
        if plugin_properties is not None:
            self.plugin_properties = plugin_properties
        if plugin_details is not None:
            self.plugin_details = plugin_details
        self.card_details = card_details
        if external_key is not None:
            self.external_key = external_key
        if is_default is not None:
            self.is_default = is_default
        if name is not None:
            self.name = name
        self.plugin_name = plugin_name
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if billing_address is not None:
            self.billing_address = billing_address

    @property
    def payment_method_id(self):
        """Gets the payment_method_id of this PaymentMethod.  # noqa: E501


        :return: The payment_method_id of this PaymentMethod.  # noqa: E501
        :rtype: str
        """
        return self._payment_method_id

    @payment_method_id.setter
    def payment_method_id(self, payment_method_id):
        """Sets the payment_method_id of this PaymentMethod.


        :param payment_method_id: The payment_method_id of this PaymentMethod.  # noqa: E501
        :type: str
        """

        self._payment_method_id = payment_method_id

    @property
    def plugin_properties(self):
        """Gets the plugin_properties of this PaymentMethod.  # noqa: E501


        :return: The plugin_properties of this PaymentMethod.  # noqa: E501
        :rtype: object
        """
        return self._plugin_properties

    @plugin_properties.setter
    def plugin_properties(self, plugin_properties):
        """Sets the plugin_properties of this PaymentMethod.


        :param plugin_properties: The plugin_properties of this PaymentMethod.  # noqa: E501
        :type: object
        """

        self._plugin_properties = plugin_properties

    @property
    def plugin_details(self):
        """Gets the plugin_details of this PaymentMethod.  # noqa: E501


        :return: The plugin_details of this PaymentMethod.  # noqa: E501
        :rtype: str
        """
        return self._plugin_details

    @plugin_details.setter
    def plugin_details(self, plugin_details):
        """Sets the plugin_details of this PaymentMethod.


        :param plugin_details: The plugin_details of this PaymentMethod.  # noqa: E501
        :type: str
        """

        self._plugin_details = plugin_details

    @property
    def card_details(self):
        """Gets the card_details of this PaymentMethod.  # noqa: E501


        :return: The card_details of this PaymentMethod.  # noqa: E501
        :rtype: CardDetails
        """
        return self._card_details

    @card_details.setter
    def card_details(self, card_details):
        """Sets the card_details of this PaymentMethod.


        :param card_details: The card_details of this PaymentMethod.  # noqa: E501
        :type: CardDetails
        """
        if card_details is None:
            raise ValueError("Invalid value for `card_details`, must not be `None`")  # noqa: E501

        self._card_details = card_details

    @property
    def external_key(self):
        """Gets the external_key of this PaymentMethod.  # noqa: E501


        :return: The external_key of this PaymentMethod.  # noqa: E501
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """Sets the external_key of this PaymentMethod.


        :param external_key: The external_key of this PaymentMethod.  # noqa: E501
        :type: str
        """

        self._external_key = external_key

    @property
    def is_default(self):
        """Gets the is_default of this PaymentMethod.  # noqa: E501


        :return: The is_default of this PaymentMethod.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this PaymentMethod.


        :param is_default: The is_default of this PaymentMethod.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def name(self):
        """Gets the name of this PaymentMethod.  # noqa: E501


        :return: The name of this PaymentMethod.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentMethod.


        :param name: The name of this PaymentMethod.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def plugin_name(self):
        """Gets the plugin_name of this PaymentMethod.  # noqa: E501


        :return: The plugin_name of this PaymentMethod.  # noqa: E501
        :rtype: str
        """
        return self._plugin_name

    @plugin_name.setter
    def plugin_name(self, plugin_name):
        """Sets the plugin_name of this PaymentMethod.


        :param plugin_name: The plugin_name of this PaymentMethod.  # noqa: E501
        :type: str
        """
        if plugin_name is None:
            raise ValueError("Invalid value for `plugin_name`, must not be `None`")  # noqa: E501

        self._plugin_name = plugin_name

    @property
    def created_at(self):
        """Gets the created_at of this PaymentMethod.  # noqa: E501


        :return: The created_at of this PaymentMethod.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PaymentMethod.


        :param created_at: The created_at of this PaymentMethod.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this PaymentMethod.  # noqa: E501


        :return: The updated_at of this PaymentMethod.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PaymentMethod.


        :param updated_at: The updated_at of this PaymentMethod.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def billing_address(self):
        """Gets the billing_address of this PaymentMethod.  # noqa: E501


        :return: The billing_address of this PaymentMethod.  # noqa: E501
        :rtype: str
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this PaymentMethod.


        :param billing_address: The billing_address of this PaymentMethod.  # noqa: E501
        :type: str
        """

        self._billing_address = billing_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentMethod, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentMethod):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_billing_client
from api.plugin_configurations_api import PluginConfigurationsApi  # noqa: E501
from spotii_billing_client.rest import ApiException


class TestPluginConfigurationsApi(unittest.TestCase):
    """PluginConfigurationsApi unit test stubs"""

    def setUp(self):
        self.api = api.plugin_configurations_api.PluginConfigurationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_plugin_configurations_create(self):
        """Test case for plugin_configurations_create

        Plugin configuration  # noqa: E501
        """
        pass

    def test_plugin_configurations_delete(self):
        """Test case for plugin_configurations_delete

        Plugin configuration  # noqa: E501
        """
        pass

    def test_plugin_configurations_list(self):
        """Test case for plugin_configurations_list

        Plugin configuration  # noqa: E501
        """
        pass

    def test_plugin_configurations_partial_update(self):
        """Test case for plugin_configurations_partial_update

        Plugin configuration  # noqa: E501
        """
        pass

    def test_plugin_configurations_read(self):
        """Test case for plugin_configurations_read

        Plugin configuration  # noqa: E501
        """
        pass

    def test_plugin_configurations_update(self):
        """Test case for plugin_configurations_update

        Plugin configuration  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from spotii_billing_client.api.accounts_api import AccountsApi
from spotii_billing_client.api.billing_addresses_api import BillingAddressesApi
from spotii_billing_client.api.configurations_api import ConfigurationsApi
from spotii_billing_client.api.installment_estimate_api import InstallmentEstimateApi
from spotii_billing_client.api.installments_api import InstallmentsApi
from spotii_billing_client.api.invoices_api import InvoicesApi
from spotii_billing_client.api.payment_methods_api import PaymentMethodsApi
from spotii_billing_client.api.payments_api import PaymentsApi
from spotii_billing_client.api.plugin_configurations_api import PluginConfigurationsApi
from spotii_billing_client.api.push_notifications_api import PushNotificationsApi
from spotii_billing_client.api.tenants_api import TenantsApi
from spotii_billing_client.api.transactions_api import TransactionsApi



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class InvoiceItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'invoice_item_id': 'str',
        'name': 'str',
        'description': 'str',
        'amount': 'str',
        'currency': 'str',
        'quantity': 'int',
        'created_at': 'datetime'
    }

    attribute_map = {
        'invoice_item_id': 'invoice_item_id',
        'name': 'name',
        'description': 'description',
        'amount': 'amount',
        'currency': 'currency',
        'quantity': 'quantity',
        'created_at': 'created_at'
    }

    def __init__(self, invoice_item_id=None, name=None, description=None, amount=None, currency=None, quantity=None, created_at=None):  # noqa: E501
        """InvoiceItem - a model defined in Swagger"""  # noqa: E501
        self._invoice_item_id = None
        self._name = None
        self._description = None
        self._amount = None
        self._currency = None
        self._quantity = None
        self._created_at = None
        self.discriminator = None
        if invoice_item_id is not None:
            self.invoice_item_id = invoice_item_id
        self.name = name
        if description is not None:
            self.description = description
        self.amount = amount
        self.currency = currency
        self.quantity = quantity
        if created_at is not None:
            self.created_at = created_at

    @property
    def invoice_item_id(self):
        """Gets the invoice_item_id of this InvoiceItem.  # noqa: E501


        :return: The invoice_item_id of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._invoice_item_id

    @invoice_item_id.setter
    def invoice_item_id(self, invoice_item_id):
        """Sets the invoice_item_id of this InvoiceItem.


        :param invoice_item_id: The invoice_item_id of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._invoice_item_id = invoice_item_id

    @property
    def name(self):
        """Gets the name of this InvoiceItem.  # noqa: E501


        :return: The name of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InvoiceItem.


        :param name: The name of this InvoiceItem.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this InvoiceItem.  # noqa: E501


        :return: The description of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InvoiceItem.


        :param description: The description of this InvoiceItem.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def amount(self):
        """Gets the amount of this InvoiceItem.  # noqa: E501


        :return: The amount of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this InvoiceItem.


        :param amount: The amount of this InvoiceItem.  # noqa: E501
        :type: str
        """
        if amount is None:
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this InvoiceItem.  # noqa: E501


        :return: The currency of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InvoiceItem.


        :param currency: The currency of this InvoiceItem.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501
        allowed_values = ["USD", "AED"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def quantity(self):
        """Gets the quantity of this InvoiceItem.  # noqa: E501


        :return: The quantity of this InvoiceItem.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this InvoiceItem.


        :param quantity: The quantity of this InvoiceItem.  # noqa: E501
        :type: int
        """
        if quantity is None:
            raise ValueError("Invalid value for `quantity`, must not be `None`")  # noqa: E501

        self._quantity = quantity

    @property
    def created_at(self):
        """Gets the created_at of this InvoiceItem.  # noqa: E501


        :return: The created_at of this InvoiceItem.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InvoiceItem.


        :param created_at: The created_at of this InvoiceItem.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvoiceItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoiceItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Payment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'payment_id': 'str',
        'transactions': 'list[Transaction]',
        'external_key': 'str',
        'object_id': 'str',
        'payment_number': 'str',
        'amount': 'str',
        'currency': 'str',
        'created_by': 'str',
        'updated_by': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'tenant': 'str',
        'account': 'str',
        'payment_method': 'str',
        'object_type': 'int'
    }

    attribute_map = {
        'payment_id': 'payment_id',
        'transactions': 'transactions',
        'external_key': 'external_key',
        'object_id': 'object_id',
        'payment_number': 'payment_number',
        'amount': 'amount',
        'currency': 'currency',
        'created_by': 'created_by',
        'updated_by': 'updated_by',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'tenant': 'tenant',
        'account': 'account',
        'payment_method': 'payment_method',
        'object_type': 'object_type'
    }

    def __init__(self, payment_id=None, transactions=None, external_key=None, object_id=None, payment_number=None, amount=None, currency=None, created_by=None, updated_by=None, created_at=None, updated_at=None, tenant=None, account=None, payment_method=None, object_type=None):  # noqa: E501
        """Payment - a model defined in Swagger"""  # noqa: E501
        self._payment_id = None
        self._transactions = None
        self._external_key = None
        self._object_id = None
        self._payment_number = None
        self._amount = None
        self._currency = None
        self._created_by = None
        self._updated_by = None
        self._created_at = None
        self._updated_at = None
        self._tenant = None
        self._account = None
        self._payment_method = None
        self._object_type = None
        self.discriminator = None
        if payment_id is not None:
            self.payment_id = payment_id
        if transactions is not None:
            self.transactions = transactions
        self.external_key = external_key
        if object_id is not None:
            self.object_id = object_id
        self.payment_number = payment_number
        self.amount = amount
        self.currency = currency
        self.created_by = created_by
        self.updated_by = updated_by
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        self.tenant = tenant
        self.account = account
        self.payment_method = payment_method
        if object_type is not None:
            self.object_type = object_type

    @property
    def payment_id(self):
        """Gets the payment_id of this Payment.  # noqa: E501


        :return: The payment_id of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._payment_id

    @payment_id.setter
    def payment_id(self, payment_id):
        """Sets the payment_id of this Payment.


        :param payment_id: The payment_id of this Payment.  # noqa: E501
        :type: str
        """

        self._payment_id = payment_id

    @property
    def transactions(self):
        """Gets the transactions of this Payment.  # noqa: E501


        :return: The transactions of this Payment.  # noqa: E501
        :rtype: list[Transaction]
        """
        return self._transactions

    @transactions.setter
    def transactions(self, transactions):
        """Sets the transactions of this Payment.


        :param transactions: The transactions of this Payment.  # noqa: E501
        :type: list[Transaction]
        """

        self._transactions = transactions

    @property
    def external_key(self):
        """Gets the external_key of this Payment.  # noqa: E501


        :return: The external_key of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """Sets the external_key of this Payment.


        :param external_key: The external_key of this Payment.  # noqa: E501
        :type: str
        """
        if external_key is None:
            raise ValueError("Invalid value for `external_key`, must not be `None`")  # noqa: E501

        self._external_key = external_key

    @property
    def object_id(self):
        """Gets the object_id of this Payment.  # noqa: E501


        :return: The object_id of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this Payment.


        :param object_id: The object_id of this Payment.  # noqa: E501
        :type: str
        """

        self._object_id = object_id

    @property
    def payment_number(self):
        """Gets the payment_number of this Payment.  # noqa: E501


        :return: The payment_number of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._payment_number

    @payment_number.setter
    def payment_number(self, payment_number):
        """Sets the payment_number of this Payment.


        :param payment_number: The payment_number of this Payment.  # noqa: E501
        :type: str
        """
        if payment_number is None:
            raise ValueError("Invalid value for `payment_number`, must not be `None`")  # noqa: E501

        self._payment_number = payment_number

    @property
    def amount(self):
        """Gets the amount of this Payment.  # noqa: E501


        :return: The amount of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Payment.


        :param amount: The amount of this Payment.  # noqa: E501
        :type: str
        """
        if amount is None:
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this Payment.  # noqa: E501


        :return: The currency of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Payment.


        :param currency: The currency of this Payment.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501
        allowed_values = ["USD", "AED"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def created_by(self):
        """Gets the created_by of this Payment.  # noqa: E501


        :return: The created_by of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Payment.


        :param created_by: The created_by of this Payment.  # noqa: E501
        :type: str
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def updated_by(self):
        """Gets the updated_by of this Payment.  # noqa: E501


        :return: The updated_by of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """Sets the updated_by of this Payment.


        :param updated_by: The updated_by of this Payment.  # noqa: E501
        :type: str
        """
        if updated_by is None:
            raise ValueError("Invalid value for `updated_by`, must not be `None`")  # noqa: E501

        self._updated_by = updated_by

    @property
    def created_at(self):
        """Gets the created_at of this Payment.  # noqa: E501


        :return: The created_at of this Payment.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Payment.


        :param created_at: The created_at of this Payment.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Payment.  # noqa: E501


        :return: The updated_at of this Payment.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Payment.


        :param updated_at: The updated_at of this Payment.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def tenant(self):
        """Gets the tenant of this Payment.  # noqa: E501


        :return: The tenant of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._tenant

    @tenant.setter
    def tenant(self, tenant):
        """Sets the tenant of this Payment.


        :param tenant: The tenant of this Payment.  # noqa: E501
        :type: str
        """
        if tenant is None:
            raise ValueError("Invalid value for `tenant`, must not be `None`")  # noqa: E501

        self._tenant = tenant

    @property
    def account(self):
        """Gets the account of this Payment.  # noqa: E501


        :return: The account of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this Payment.


        :param account: The account of this Payment.  # noqa: E501
        :type: str
        """
        if account is None:
            raise ValueError("Invalid value for `account`, must not be `None`")  # noqa: E501

        self._account = account

    @property
    def payment_method(self):
        """Gets the payment_method of this Payment.  # noqa: E501


        :return: The payment_method of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this Payment.


        :param payment_method: The payment_method of this Payment.  # noqa: E501
        :type: str
        """
        if payment_method is None:
            raise ValueError("Invalid value for `payment_method`, must not be `None`")  # noqa: E501

        self._payment_method = payment_method

    @property
    def object_type(self):
        """Gets the object_type of this Payment.  # noqa: E501


        :return: The object_type of this Payment.  # noqa: E501
        :rtype: int
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """Sets the object_type of this Payment.


        :param object_type: The object_type of this Payment.  # noqa: E501
        :type: int
        """

        self._object_type = object_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Payment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Payment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from spotii_billing_client.api.accounts_api import AccountsApi
from spotii_billing_client.api.billing_addresses_api import BillingAddressesApi
from spotii_billing_client.api.configurations_api import ConfigurationsApi
from spotii_billing_client.api.installment_estimate_api import InstallmentEstimateApi
from spotii_billing_client.api.installments_api import InstallmentsApi
from spotii_billing_client.api.invoices_api import InvoicesApi
from spotii_billing_client.api.payment_methods_api import PaymentMethodsApi
from spotii_billing_client.api.payments_api import PaymentsApi
from spotii_billing_client.api.plugin_configurations_api import PluginConfigurationsApi
from spotii_billing_client.api.push_notifications_api import PushNotificationsApi
from spotii_billing_client.api.tenants_api import TenantsApi
from spotii_billing_client.api.transactions_api import TransactionsApi
# import ApiClient
from spotii_billing_client.api_client import ApiClient
from spotii_billing_client.configuration import Configuration
# import models into sdk package
from spotii_billing_client.models.account import Account
from spotii_billing_client.models.billing_address import BillingAddress
from spotii_billing_client.models.calculated_payments_serilizer import CalculatedPaymentsSerilizer
from spotii_billing_client.models.card_details import CardDetails
from spotii_billing_client.models.configuration import Configuration
from spotii_billing_client.models.configuration_update import ConfigurationUpdate
from spotii_billing_client.models.esstimation_payment_serilizer import EsstimationPaymentSerilizer
from spotii_billing_client.models.estimation import Estimation
from spotii_billing_client.models.installment_serilizer import InstallmentSerilizer
from spotii_billing_client.models.installments import Installments
from spotii_billing_client.models.invoice import Invoice
from spotii_billing_client.models.invoice_item import InvoiceItem
from spotii_billing_client.models.payment import Payment
from spotii_billing_client.models.payment_method import PaymentMethod
from spotii_billing_client.models.plugin_configuration import PluginConfiguration
from spotii_billing_client.models.plugin_configuration_update import PluginConfigurationUpdate
from spotii_billing_client.models.push_notification import PushNotification
from spotii_billing_client.models.tenant import Tenant
from spotii_billing_client.models.transaction import Transaction



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class InstallmentSerilizer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'installment_id': 'str',
        'effective_at': 'datetime',
        'status': 'str',
        'phase_id': 'str',
        'amount': 'str',
        'currency': 'str',
        'payments': 'list[EsstimationPaymentSerilizer]'
    }

    attribute_map = {
        'installment_id': 'installment_id',
        'effective_at': 'effective_at',
        'status': 'status',
        'phase_id': 'phase_id',
        'amount': 'amount',
        'currency': 'currency',
        'payments': 'payments'
    }

    def __init__(self, installment_id=None, effective_at=None, status=None, phase_id=None, amount=None, currency=None, payments=None):  # noqa: E501
        """InstallmentSerilizer - a model defined in Swagger"""  # noqa: E501
        self._installment_id = None
        self._effective_at = None
        self._status = None
        self._phase_id = None
        self._amount = None
        self._currency = None
        self._payments = None
        self.discriminator = None
        if installment_id is not None:
            self.installment_id = installment_id
        self.effective_at = effective_at
        if status is not None:
            self.status = status
        if phase_id is not None:
            self.phase_id = phase_id
        self.amount = amount
        self.currency = currency
        self.payments = payments

    @property
    def installment_id(self):
        """Gets the installment_id of this InstallmentSerilizer.  # noqa: E501


        :return: The installment_id of this InstallmentSerilizer.  # noqa: E501
        :rtype: str
        """
        return self._installment_id

    @installment_id.setter
    def installment_id(self, installment_id):
        """Sets the installment_id of this InstallmentSerilizer.


        :param installment_id: The installment_id of this InstallmentSerilizer.  # noqa: E501
        :type: str
        """

        self._installment_id = installment_id

    @property
    def effective_at(self):
        """Gets the effective_at of this InstallmentSerilizer.  # noqa: E501


        :return: The effective_at of this InstallmentSerilizer.  # noqa: E501
        :rtype: datetime
        """
        return self._effective_at

    @effective_at.setter
    def effective_at(self, effective_at):
        """Sets the effective_at of this InstallmentSerilizer.


        :param effective_at: The effective_at of this InstallmentSerilizer.  # noqa: E501
        :type: datetime
        """
        if effective_at is None:
            raise ValueError("Invalid value for `effective_at`, must not be `None`")  # noqa: E501

        self._effective_at = effective_at

    @property
    def status(self):
        """Gets the status of this InstallmentSerilizer.  # noqa: E501


        :return: The status of this InstallmentSerilizer.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InstallmentSerilizer.


        :param status: The status of this InstallmentSerilizer.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def phase_id(self):
        """Gets the phase_id of this InstallmentSerilizer.  # noqa: E501


        :return: The phase_id of this InstallmentSerilizer.  # noqa: E501
        :rtype: str
        """
        return self._phase_id

    @phase_id.setter
    def phase_id(self, phase_id):
        """Sets the phase_id of this InstallmentSerilizer.


        :param phase_id: The phase_id of this InstallmentSerilizer.  # noqa: E501
        :type: str
        """

        self._phase_id = phase_id

    @property
    def amount(self):
        """Gets the amount of this InstallmentSerilizer.  # noqa: E501


        :return: The amount of this InstallmentSerilizer.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this InstallmentSerilizer.


        :param amount: The amount of this InstallmentSerilizer.  # noqa: E501
        :type: str
        """
        if amount is None:
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this InstallmentSerilizer.  # noqa: E501


        :return: The currency of this InstallmentSerilizer.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InstallmentSerilizer.


        :param currency: The currency of this InstallmentSerilizer.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501

        self._currency = currency

    @property
    def payments(self):
        """Gets the payments of this InstallmentSerilizer.  # noqa: E501


        :return: The payments of this InstallmentSerilizer.  # noqa: E501
        :rtype: list[EsstimationPaymentSerilizer]
        """
        return self._payments

    @payments.setter
    def payments(self, payments):
        """Sets the payments of this InstallmentSerilizer.


        :param payments: The payments of this InstallmentSerilizer.  # noqa: E501
        :type: list[EsstimationPaymentSerilizer]
        """
        if payments is None:
            raise ValueError("Invalid value for `payments`, must not be `None`")  # noqa: E501

        self._payments = payments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InstallmentSerilizer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstallmentSerilizer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_billing_client
from api.accounts_api import AccountsApi  # noqa: E501
from spotii_billing_client.rest import ApiException


class TestAccountsApi(unittest.TestCase):
    """AccountsApi unit test stubs"""

    def setUp(self):
        self.api = api.accounts_api.AccountsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_accounts_billing_addresses_create(self):
        """Test case for accounts_billing_addresses_create

        """
        pass

    def test_accounts_billing_addresses_default(self):
        """Test case for accounts_billing_addresses_default

        """
        pass

    def test_accounts_billing_addresses_delete(self):
        """Test case for accounts_billing_addresses_delete

        """
        pass

    def test_accounts_billing_addresses_list(self):
        """Test case for accounts_billing_addresses_list

        """
        pass

    def test_accounts_billing_addresses_partial_update(self):
        """Test case for accounts_billing_addresses_partial_update

        """
        pass

    def test_accounts_billing_addresses_read(self):
        """Test case for accounts_billing_addresses_read

        """
        pass

    def test_accounts_billing_addresses_update(self):
        """Test case for accounts_billing_addresses_update

        """
        pass

    def test_accounts_create(self):
        """Test case for accounts_create

        """
        pass

    def test_accounts_installments_create(self):
        """Test case for accounts_installments_create

        """
        pass

    def test_accounts_installments_delete(self):
        """Test case for accounts_installments_delete

        """
        pass

    def test_accounts_installments_list(self):
        """Test case for accounts_installments_list

        """
        pass

    def test_accounts_installments_read(self):
        """Test case for accounts_installments_read

        """
        pass

    def test_accounts_list(self):
        """Test case for accounts_list

        """
        pass

    def test_accounts_partial_update(self):
        """Test case for accounts_partial_update

        """
        pass

    def test_accounts_payment_methods_create(self):
        """Test case for accounts_payment_methods_create

        """
        pass

    def test_accounts_payment_methods_default(self):
        """Test case for accounts_payment_methods_default

        """
        pass

    def test_accounts_payment_methods_delete(self):
        """Test case for accounts_payment_methods_delete

        """
        pass

    def test_accounts_payment_methods_list(self):
        """Test case for accounts_payment_methods_list

        """
        pass

    def test_accounts_payment_methods_partial_update(self):
        """Test case for accounts_payment_methods_partial_update

        """
        pass

    def test_accounts_payment_methods_read(self):
        """Test case for accounts_payment_methods_read

        """
        pass

    def test_accounts_payment_methods_update(self):
        """Test case for accounts_payment_methods_update

        """
        pass

    def test_accounts_payments_list(self):
        """Test case for accounts_payments_list

        API endpoint that allow access to payment.  # noqa: E501
        """
        pass

    def test_accounts_payments_read(self):
        """Test case for accounts_payments_read

        API endpoint that allow access to payment.  # noqa: E501
        """
        pass

    def test_accounts_read(self):
        """Test case for accounts_read

        """
        pass

    def test_accounts_update(self):
        """Test case for accounts_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from spotii_billing_client.models.account import Account
from spotii_billing_client.models.billing_address import BillingAddress
from spotii_billing_client.models.calculated_payments_serilizer import CalculatedPaymentsSerilizer
from spotii_billing_client.models.card_details import CardDetails
from spotii_billing_client.models.configuration import Configuration
from spotii_billing_client.models.configuration_update import ConfigurationUpdate
from spotii_billing_client.models.esstimation_payment_serilizer import EsstimationPaymentSerilizer
from spotii_billing_client.models.estimation import Estimation
from spotii_billing_client.models.installment_serilizer import InstallmentSerilizer
from spotii_billing_client.models.installments import Installments
from spotii_billing_client.models.invoice import Invoice
from spotii_billing_client.models.invoice_item import InvoiceItem
from spotii_billing_client.models.payment import Payment
from spotii_billing_client.models.payment_method import PaymentMethod
from spotii_billing_client.models.plugin_configuration import PluginConfiguration
from spotii_billing_client.models.plugin_configuration_update import PluginConfigurationUpdate
from spotii_billing_client.models.push_notification import PushNotification
from spotii_billing_client.models.tenant import Tenant
from spotii_billing_client.models.transaction import Transaction



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from spotii_billing_client.api_client import ApiClient


class InvoicesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def invoices_list(self, **kwargs):  # noqa: E501
        """The invoice resource represents a specific invoice associated with a given account.  # noqa: E501

        User can generate ivoice by provided apis to add credit or create charges againts the account. Invoices can also be automatically generated by system against the account, for instance by installment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_key:
        :return: list[Invoice]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invoices_list_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.invoices_list_with_http_info(**kwargs)  # noqa: E501
            return data

    def invoices_list_with_http_info(self, **kwargs):  # noqa: E501
        """The invoice resource represents a specific invoice associated with a given account.  # noqa: E501

        User can generate ivoice by provided apis to add credit or create charges againts the account. Invoices can also be automatically generated by system against the account, for instance by installment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_key:
        :return: list[Invoice]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['external_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invoices_list" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'external_key' in params:
            query_params.append(('external_key', params['external_key']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/invoices/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Invoice]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invoices_read(self, invoice_id, **kwargs):  # noqa: E501
        """The invoice resource represents a specific invoice associated with a given account.  # noqa: E501

        User can generate ivoice by provided apis to add credit or create charges againts the account. Invoices can also be automatically generated by system against the account, for instance by installment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_read(invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str invoice_id: A UUID string identifying this invoice. (required)
        :return: Invoice
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invoices_read_with_http_info(invoice_id, **kwargs)  # noqa: E501
        else:
            (data) = self.invoices_read_with_http_info(invoice_id, **kwargs)  # noqa: E501
            return data

    def invoices_read_with_http_info(self, invoice_id, **kwargs):  # noqa: E501
        """The invoice resource represents a specific invoice associated with a given account.  # noqa: E501

        User can generate ivoice by provided apis to add credit or create charges againts the account. Invoices can also be automatically generated by system against the account, for instance by installment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_read_with_http_info(invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str invoice_id: A UUID string identifying this invoice. (required)
        :return: Invoice
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['invoice_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invoices_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'invoice_id' is set
        if ('invoice_id' not in params or
                params['invoice_id'] is None):
            raise ValueError("Missing the required parameter `invoice_id` when calling `invoices_read`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'invoice_id' in params:
            path_params['invoice_id'] = params['invoice_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/invoices/{invoice_id}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Invoice',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Installments(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'installments_id': 'str',
        'external_key': 'str',
        'installments_number': 'str',
        'plan_id': 'str',
        'installments': 'list[InstallmentSerilizer]',
        'payment_method_id': 'str',
        'amount': 'str',
        'currency': 'str',
        'status': 'str',
        'created_at': 'datetime'
    }

    attribute_map = {
        'installments_id': 'installments_id',
        'external_key': 'external_key',
        'installments_number': 'installments_number',
        'plan_id': 'plan_id',
        'installments': 'installments',
        'payment_method_id': 'payment_method_id',
        'amount': 'amount',
        'currency': 'currency',
        'status': 'status',
        'created_at': 'created_at'
    }

    def __init__(self, installments_id=None, external_key=None, installments_number=None, plan_id=None, installments=None, payment_method_id=None, amount=None, currency=None, status=None, created_at=None):  # noqa: E501
        """Installments - a model defined in Swagger"""  # noqa: E501
        self._installments_id = None
        self._external_key = None
        self._installments_number = None
        self._plan_id = None
        self._installments = None
        self._payment_method_id = None
        self._amount = None
        self._currency = None
        self._status = None
        self._created_at = None
        self.discriminator = None
        if installments_id is not None:
            self.installments_id = installments_id
        self.external_key = external_key
        if installments_number is not None:
            self.installments_number = installments_number
        self.plan_id = plan_id
        if installments is not None:
            self.installments = installments
        if payment_method_id is not None:
            self.payment_method_id = payment_method_id
        self.amount = amount
        self.currency = currency
        if status is not None:
            self.status = status
        if created_at is not None:
            self.created_at = created_at

    @property
    def installments_id(self):
        """Gets the installments_id of this Installments.  # noqa: E501


        :return: The installments_id of this Installments.  # noqa: E501
        :rtype: str
        """
        return self._installments_id

    @installments_id.setter
    def installments_id(self, installments_id):
        """Sets the installments_id of this Installments.


        :param installments_id: The installments_id of this Installments.  # noqa: E501
        :type: str
        """

        self._installments_id = installments_id

    @property
    def external_key(self):
        """Gets the external_key of this Installments.  # noqa: E501


        :return: The external_key of this Installments.  # noqa: E501
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """Sets the external_key of this Installments.


        :param external_key: The external_key of this Installments.  # noqa: E501
        :type: str
        """
        if external_key is None:
            raise ValueError("Invalid value for `external_key`, must not be `None`")  # noqa: E501

        self._external_key = external_key

    @property
    def installments_number(self):
        """Gets the installments_number of this Installments.  # noqa: E501


        :return: The installments_number of this Installments.  # noqa: E501
        :rtype: str
        """
        return self._installments_number

    @installments_number.setter
    def installments_number(self, installments_number):
        """Sets the installments_number of this Installments.


        :param installments_number: The installments_number of this Installments.  # noqa: E501
        :type: str
        """

        self._installments_number = installments_number

    @property
    def plan_id(self):
        """Gets the plan_id of this Installments.  # noqa: E501


        :return: The plan_id of this Installments.  # noqa: E501
        :rtype: str
        """
        return self._plan_id

    @plan_id.setter
    def plan_id(self, plan_id):
        """Sets the plan_id of this Installments.


        :param plan_id: The plan_id of this Installments.  # noqa: E501
        :type: str
        """
        if plan_id is None:
            raise ValueError("Invalid value for `plan_id`, must not be `None`")  # noqa: E501

        self._plan_id = plan_id

    @property
    def installments(self):
        """Gets the installments of this Installments.  # noqa: E501


        :return: The installments of this Installments.  # noqa: E501
        :rtype: list[InstallmentSerilizer]
        """
        return self._installments

    @installments.setter
    def installments(self, installments):
        """Sets the installments of this Installments.


        :param installments: The installments of this Installments.  # noqa: E501
        :type: list[InstallmentSerilizer]
        """

        self._installments = installments

    @property
    def payment_method_id(self):
        """Gets the payment_method_id of this Installments.  # noqa: E501


        :return: The payment_method_id of this Installments.  # noqa: E501
        :rtype: str
        """
        return self._payment_method_id

    @payment_method_id.setter
    def payment_method_id(self, payment_method_id):
        """Sets the payment_method_id of this Installments.


        :param payment_method_id: The payment_method_id of this Installments.  # noqa: E501
        :type: str
        """

        self._payment_method_id = payment_method_id

    @property
    def amount(self):
        """Gets the amount of this Installments.  # noqa: E501


        :return: The amount of this Installments.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Installments.


        :param amount: The amount of this Installments.  # noqa: E501
        :type: str
        """
        if amount is None:
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this Installments.  # noqa: E501


        :return: The currency of this Installments.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Installments.


        :param currency: The currency of this Installments.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501
        allowed_values = ["USD", "AED"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def status(self):
        """Gets the status of this Installments.  # noqa: E501


        :return: The status of this Installments.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Installments.


        :param status: The status of this Installments.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def created_at(self):
        """Gets the created_at of this Installments.  # noqa: E501


        :return: The created_at of this Installments.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Installments.


        :param created_at: The created_at of this Installments.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Installments, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Installments):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_billing_client
from api.billing_addresses_api import BillingAddressesApi  # noqa: E501
from spotii_billing_client.rest import ApiException


class TestBillingAddressesApi(unittest.TestCase):
    """BillingAddressesApi unit test stubs"""

    def setUp(self):
        self.api = api.billing_addresses_api.BillingAddressesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_billing_addresses_create(self):
        """Test case for billing_addresses_create

        """
        pass

    def test_billing_addresses_default(self):
        """Test case for billing_addresses_default

        """
        pass

    def test_billing_addresses_delete(self):
        """Test case for billing_addresses_delete

        """
        pass

    def test_billing_addresses_list(self):
        """Test case for billing_addresses_list

        """
        pass

    def test_billing_addresses_partial_update(self):
        """Test case for billing_addresses_partial_update

        """
        pass

    def test_billing_addresses_read(self):
        """Test case for billing_addresses_read

        """
        pass

    def test_billing_addresses_update(self):
        """Test case for billing_addresses_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_billing_client
from api.installment_estimate_api import InstallmentEstimateApi  # noqa: E501
from spotii_billing_client.rest import ApiException


class TestInstallmentEstimateApi(unittest.TestCase):
    """InstallmentEstimateApi unit test stubs"""

    def setUp(self):
        self.api = api.installment_estimate_api.InstallmentEstimateApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_installment_estimate_create(self):
        """Test case for installment_estimate_create

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class BillingAddress(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'billing_address_id': 'str',
        'external_key': 'str',
        'name': 'str',
        'first_name_len': 'int',
        'email': 'str',
        'phone': 'str',
        'country': 'str',
        'city': 'str',
        'state': 'str',
        'address1': 'str',
        'address2': 'str',
        'address3': 'str',
        'postal_code': 'str',
        'company': 'str',
        'notes': 'str',
        'is_default': 'bool',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'deleted_at': 'datetime'
    }

    attribute_map = {
        'billing_address_id': 'billing_address_id',
        'external_key': 'external_key',
        'name': 'name',
        'first_name_len': 'first_name_len',
        'email': 'email',
        'phone': 'phone',
        'country': 'country',
        'city': 'city',
        'state': 'state',
        'address1': 'address1',
        'address2': 'address2',
        'address3': 'address3',
        'postal_code': 'postal_code',
        'company': 'company',
        'notes': 'notes',
        'is_default': 'is_default',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'deleted_at': 'deleted_at'
    }

    def __init__(self, billing_address_id=None, external_key=None, name=None, first_name_len=None, email=None, phone=None, country=None, city=None, state=None, address1=None, address2=None, address3=None, postal_code=None, company=None, notes=None, is_default=None, created_at=None, updated_at=None, deleted_at=None):  # noqa: E501
        """BillingAddress - a model defined in Swagger"""  # noqa: E501
        self._billing_address_id = None
        self._external_key = None
        self._name = None
        self._first_name_len = None
        self._email = None
        self._phone = None
        self._country = None
        self._city = None
        self._state = None
        self._address1 = None
        self._address2 = None
        self._address3 = None
        self._postal_code = None
        self._company = None
        self._notes = None
        self._is_default = None
        self._created_at = None
        self._updated_at = None
        self._deleted_at = None
        self.discriminator = None
        if billing_address_id is not None:
            self.billing_address_id = billing_address_id
        if external_key is not None:
            self.external_key = external_key
        if name is not None:
            self.name = name
        if first_name_len is not None:
            self.first_name_len = first_name_len
        if email is not None:
            self.email = email
        if phone is not None:
            self.phone = phone
        if country is not None:
            self.country = country
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if address1 is not None:
            self.address1 = address1
        if address2 is not None:
            self.address2 = address2
        if address3 is not None:
            self.address3 = address3
        if postal_code is not None:
            self.postal_code = postal_code
        if company is not None:
            self.company = company
        if notes is not None:
            self.notes = notes
        if is_default is not None:
            self.is_default = is_default
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if deleted_at is not None:
            self.deleted_at = deleted_at

    @property
    def billing_address_id(self):
        """Gets the billing_address_id of this BillingAddress.  # noqa: E501


        :return: The billing_address_id of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._billing_address_id

    @billing_address_id.setter
    def billing_address_id(self, billing_address_id):
        """Sets the billing_address_id of this BillingAddress.


        :param billing_address_id: The billing_address_id of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._billing_address_id = billing_address_id

    @property
    def external_key(self):
        """Gets the external_key of this BillingAddress.  # noqa: E501


        :return: The external_key of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """Sets the external_key of this BillingAddress.


        :param external_key: The external_key of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._external_key = external_key

    @property
    def name(self):
        """Gets the name of this BillingAddress.  # noqa: E501


        :return: The name of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BillingAddress.


        :param name: The name of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def first_name_len(self):
        """Gets the first_name_len of this BillingAddress.  # noqa: E501


        :return: The first_name_len of this BillingAddress.  # noqa: E501
        :rtype: int
        """
        return self._first_name_len

    @first_name_len.setter
    def first_name_len(self, first_name_len):
        """Sets the first_name_len of this BillingAddress.


        :param first_name_len: The first_name_len of this BillingAddress.  # noqa: E501
        :type: int
        """

        self._first_name_len = first_name_len

    @property
    def email(self):
        """Gets the email of this BillingAddress.  # noqa: E501


        :return: The email of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this BillingAddress.


        :param email: The email of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def phone(self):
        """Gets the phone of this BillingAddress.  # noqa: E501


        :return: The phone of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this BillingAddress.


        :param phone: The phone of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def country(self):
        """Gets the country of this BillingAddress.  # noqa: E501


        :return: The country of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this BillingAddress.


        :param country: The country of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def city(self):
        """Gets the city of this BillingAddress.  # noqa: E501


        :return: The city of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this BillingAddress.


        :param city: The city of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this BillingAddress.  # noqa: E501


        :return: The state of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BillingAddress.


        :param state: The state of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def address1(self):
        """Gets the address1 of this BillingAddress.  # noqa: E501


        :return: The address1 of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """Sets the address1 of this BillingAddress.


        :param address1: The address1 of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._address1 = address1

    @property
    def address2(self):
        """Gets the address2 of this BillingAddress.  # noqa: E501


        :return: The address2 of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._address2

    @address2.setter
    def address2(self, address2):
        """Sets the address2 of this BillingAddress.


        :param address2: The address2 of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._address2 = address2

    @property
    def address3(self):
        """Gets the address3 of this BillingAddress.  # noqa: E501


        :return: The address3 of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._address3

    @address3.setter
    def address3(self, address3):
        """Sets the address3 of this BillingAddress.


        :param address3: The address3 of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._address3 = address3

    @property
    def postal_code(self):
        """Gets the postal_code of this BillingAddress.  # noqa: E501


        :return: The postal_code of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this BillingAddress.


        :param postal_code: The postal_code of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def company(self):
        """Gets the company of this BillingAddress.  # noqa: E501


        :return: The company of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this BillingAddress.


        :param company: The company of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def notes(self):
        """Gets the notes of this BillingAddress.  # noqa: E501


        :return: The notes of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this BillingAddress.


        :param notes: The notes of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._notes = notes

    @property
    def is_default(self):
        """Gets the is_default of this BillingAddress.  # noqa: E501


        :return: The is_default of this BillingAddress.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this BillingAddress.


        :param is_default: The is_default of this BillingAddress.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def created_at(self):
        """Gets the created_at of this BillingAddress.  # noqa: E501


        :return: The created_at of this BillingAddress.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BillingAddress.


        :param created_at: The created_at of this BillingAddress.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this BillingAddress.  # noqa: E501


        :return: The updated_at of this BillingAddress.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this BillingAddress.


        :param updated_at: The updated_at of this BillingAddress.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def deleted_at(self):
        """Gets the deleted_at of this BillingAddress.  # noqa: E501


        :return: The deleted_at of this BillingAddress.  # noqa: E501
        :rtype: datetime
        """
        return self._deleted_at

    @deleted_at.setter
    def deleted_at(self, deleted_at):
        """Sets the deleted_at of this BillingAddress.


        :param deleted_at: The deleted_at of this BillingAddress.  # noqa: E501
        :type: datetime
        """

        self._deleted_at = deleted_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BillingAddress, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BillingAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Tenant(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tenant_id': 'str',
        'external_key': 'str',
        'name': 'str',
        'client_key': 'str',
        'client_secret': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'deleted_at': 'datetime'
    }

    attribute_map = {
        'tenant_id': 'tenant_id',
        'external_key': 'external_key',
        'name': 'name',
        'client_key': 'client_key',
        'client_secret': 'client_secret',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'deleted_at': 'deleted_at'
    }

    def __init__(self, tenant_id=None, external_key=None, name=None, client_key=None, client_secret=None, created_at=None, updated_at=None, deleted_at=None):  # noqa: E501
        """Tenant - a model defined in Swagger"""  # noqa: E501
        self._tenant_id = None
        self._external_key = None
        self._name = None
        self._client_key = None
        self._client_secret = None
        self._created_at = None
        self._updated_at = None
        self._deleted_at = None
        self.discriminator = None
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if external_key is not None:
            self.external_key = external_key
        self.name = name
        self.client_key = client_key
        self.client_secret = client_secret
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if deleted_at is not None:
            self.deleted_at = deleted_at

    @property
    def tenant_id(self):
        """Gets the tenant_id of this Tenant.  # noqa: E501


        :return: The tenant_id of this Tenant.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this Tenant.


        :param tenant_id: The tenant_id of this Tenant.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def external_key(self):
        """Gets the external_key of this Tenant.  # noqa: E501


        :return: The external_key of this Tenant.  # noqa: E501
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """Sets the external_key of this Tenant.


        :param external_key: The external_key of this Tenant.  # noqa: E501
        :type: str
        """

        self._external_key = external_key

    @property
    def name(self):
        """Gets the name of this Tenant.  # noqa: E501


        :return: The name of this Tenant.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Tenant.


        :param name: The name of this Tenant.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def client_key(self):
        """Gets the client_key of this Tenant.  # noqa: E501


        :return: The client_key of this Tenant.  # noqa: E501
        :rtype: str
        """
        return self._client_key

    @client_key.setter
    def client_key(self, client_key):
        """Sets the client_key of this Tenant.


        :param client_key: The client_key of this Tenant.  # noqa: E501
        :type: str
        """
        if client_key is None:
            raise ValueError("Invalid value for `client_key`, must not be `None`")  # noqa: E501

        self._client_key = client_key

    @property
    def client_secret(self):
        """Gets the client_secret of this Tenant.  # noqa: E501


        :return: The client_secret of this Tenant.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this Tenant.


        :param client_secret: The client_secret of this Tenant.  # noqa: E501
        :type: str
        """
        if client_secret is None:
            raise ValueError("Invalid value for `client_secret`, must not be `None`")  # noqa: E501

        self._client_secret = client_secret

    @property
    def created_at(self):
        """Gets the created_at of this Tenant.  # noqa: E501


        :return: The created_at of this Tenant.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Tenant.


        :param created_at: The created_at of this Tenant.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Tenant.  # noqa: E501


        :return: The updated_at of this Tenant.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Tenant.


        :param updated_at: The updated_at of this Tenant.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def deleted_at(self):
        """Gets the deleted_at of this Tenant.  # noqa: E501


        :return: The deleted_at of this Tenant.  # noqa: E501
        :rtype: datetime
        """
        return self._deleted_at

    @deleted_at.setter
    def deleted_at(self, deleted_at):
        """Sets the deleted_at of this Tenant.


        :param deleted_at: The deleted_at of this Tenant.  # noqa: E501
        :type: datetime
        """

        self._deleted_at = deleted_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Tenant, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Tenant):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_billing_client
from api.transactions_api import TransactionsApi  # noqa: E501
from spotii_billing_client.rest import ApiException


class TestTransactionsApi(unittest.TestCase):
    """TransactionsApi unit test stubs"""

    def setUp(self):
        self.api = api.transactions_api.TransactionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_transactions_list(self):
        """Test case for transactions_list

        API endpoint that allow access to payment transactions. Transaction belong to a Payment object.  # noqa: E501
        """
        pass

    def test_transactions_read(self):
        """Test case for transactions_read

        API endpoint that allow access to payment transactions. Transaction belong to a Payment object.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CardDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'number': 'str',
        'expiration_month': 'str',
        'expiration_year': 'str',
        'cvv': 'str',
        'holder': 'str'
    }

    attribute_map = {
        'number': 'number',
        'expiration_month': 'expiration_month',
        'expiration_year': 'expiration_year',
        'cvv': 'cvv',
        'holder': 'holder'
    }

    def __init__(self, number=None, expiration_month=None, expiration_year=None, cvv=None, holder=None):  # noqa: E501
        """CardDetails - a model defined in Swagger"""  # noqa: E501
        self._number = None
        self._expiration_month = None
        self._expiration_year = None
        self._cvv = None
        self._holder = None
        self.discriminator = None
        self.number = number
        self.expiration_month = expiration_month
        self.expiration_year = expiration_year
        if cvv is not None:
            self.cvv = cvv
        if holder is not None:
            self.holder = holder

    @property
    def number(self):
        """Gets the number of this CardDetails.  # noqa: E501


        :return: The number of this CardDetails.  # noqa: E501
        :rtype: str
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this CardDetails.


        :param number: The number of this CardDetails.  # noqa: E501
        :type: str
        """
        if number is None:
            raise ValueError("Invalid value for `number`, must not be `None`")  # noqa: E501

        self._number = number

    @property
    def expiration_month(self):
        """Gets the expiration_month of this CardDetails.  # noqa: E501


        :return: The expiration_month of this CardDetails.  # noqa: E501
        :rtype: str
        """
        return self._expiration_month

    @expiration_month.setter
    def expiration_month(self, expiration_month):
        """Sets the expiration_month of this CardDetails.


        :param expiration_month: The expiration_month of this CardDetails.  # noqa: E501
        :type: str
        """
        if expiration_month is None:
            raise ValueError("Invalid value for `expiration_month`, must not be `None`")  # noqa: E501
        allowed_values = ["01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12"]  # noqa: E501
        if expiration_month not in allowed_values:
            raise ValueError(
                "Invalid value for `expiration_month` ({0}), must be one of {1}"  # noqa: E501
                .format(expiration_month, allowed_values)
            )

        self._expiration_month = expiration_month

    @property
    def expiration_year(self):
        """Gets the expiration_year of this CardDetails.  # noqa: E501


        :return: The expiration_year of this CardDetails.  # noqa: E501
        :rtype: str
        """
        return self._expiration_year

    @expiration_year.setter
    def expiration_year(self, expiration_year):
        """Sets the expiration_year of this CardDetails.


        :param expiration_year: The expiration_year of this CardDetails.  # noqa: E501
        :type: str
        """
        if expiration_year is None:
            raise ValueError("Invalid value for `expiration_year`, must not be `None`")  # noqa: E501
        allowed_values = ["2019", "2020", "2021", "2022", "2023", "2024", "2025", "2026", "2027", "2028", "2029"]  # noqa: E501
        if expiration_year not in allowed_values:
            raise ValueError(
                "Invalid value for `expiration_year` ({0}), must be one of {1}"  # noqa: E501
                .format(expiration_year, allowed_values)
            )

        self._expiration_year = expiration_year

    @property
    def cvv(self):
        """Gets the cvv of this CardDetails.  # noqa: E501


        :return: The cvv of this CardDetails.  # noqa: E501
        :rtype: str
        """
        return self._cvv

    @cvv.setter
    def cvv(self, cvv):
        """Sets the cvv of this CardDetails.


        :param cvv: The cvv of this CardDetails.  # noqa: E501
        :type: str
        """

        self._cvv = cvv

    @property
    def holder(self):
        """Gets the holder of this CardDetails.  # noqa: E501


        :return: The holder of this CardDetails.  # noqa: E501
        :rtype: str
        """
        return self._holder

    @holder.setter
    def holder(self, holder):
        """Sets the holder of this CardDetails.


        :param holder: The holder of this CardDetails.  # noqa: E501
        :type: str
        """

        self._holder = holder

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CardDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CardDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from spotii_billing_client.api_client import ApiClient


class PaymentMethodsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def payment_methods_create(self, body, **kwargs):  # noqa: E501
        """payment_methods_create  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_create(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PaymentMethod body: (required)
        :return: PaymentMethod
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.payment_methods_create_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.payment_methods_create_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def payment_methods_create_with_http_info(self, body, **kwargs):  # noqa: E501
        """payment_methods_create  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_create_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PaymentMethod body: (required)
        :return: PaymentMethod
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method payment_methods_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `payment_methods_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/payment_methods/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaymentMethod',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def payment_methods_default(self, **kwargs):  # noqa: E501
        """payment_methods_default  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_default(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_key:
        :return: list[PaymentMethod]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.payment_methods_default_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.payment_methods_default_with_http_info(**kwargs)  # noqa: E501
            return data

    def payment_methods_default_with_http_info(self, **kwargs):  # noqa: E501
        """payment_methods_default  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_default_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_key:
        :return: list[PaymentMethod]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['external_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method payment_methods_default" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'external_key' in params:
            query_params.append(('external_key', params['external_key']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/payment_methods/default/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PaymentMethod]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def payment_methods_delete(self, payment_method_id, **kwargs):  # noqa: E501
        """payment_methods_delete  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_delete(payment_method_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str payment_method_id: A UUID string identifying this payment method. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.payment_methods_delete_with_http_info(payment_method_id, **kwargs)  # noqa: E501
        else:
            (data) = self.payment_methods_delete_with_http_info(payment_method_id, **kwargs)  # noqa: E501
            return data

    def payment_methods_delete_with_http_info(self, payment_method_id, **kwargs):  # noqa: E501
        """payment_methods_delete  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_delete_with_http_info(payment_method_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str payment_method_id: A UUID string identifying this payment method. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['payment_method_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method payment_methods_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'payment_method_id' is set
        if ('payment_method_id' not in params or
                params['payment_method_id'] is None):
            raise ValueError("Missing the required parameter `payment_method_id` when calling `payment_methods_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'payment_method_id' in params:
            path_params['payment_method_id'] = params['payment_method_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/payment_methods/{payment_method_id}/', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def payment_methods_list(self, **kwargs):  # noqa: E501
        """payment_methods_list  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_key:
        :return: list[PaymentMethod]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.payment_methods_list_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.payment_methods_list_with_http_info(**kwargs)  # noqa: E501
            return data

    def payment_methods_list_with_http_info(self, **kwargs):  # noqa: E501
        """payment_methods_list  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_key:
        :return: list[PaymentMethod]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['external_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method payment_methods_list" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'external_key' in params:
            query_params.append(('external_key', params['external_key']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/payment_methods/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PaymentMethod]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def payment_methods_partial_update(self, body, payment_method_id, **kwargs):  # noqa: E501
        """payment_methods_partial_update  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_partial_update(body, payment_method_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PaymentMethod body: (required)
        :param str payment_method_id: A UUID string identifying this payment method. (required)
        :return: PaymentMethod
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.payment_methods_partial_update_with_http_info(body, payment_method_id, **kwargs)  # noqa: E501
        else:
            (data) = self.payment_methods_partial_update_with_http_info(body, payment_method_id, **kwargs)  # noqa: E501
            return data

    def payment_methods_partial_update_with_http_info(self, body, payment_method_id, **kwargs):  # noqa: E501
        """payment_methods_partial_update  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_partial_update_with_http_info(body, payment_method_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PaymentMethod body: (required)
        :param str payment_method_id: A UUID string identifying this payment method. (required)
        :return: PaymentMethod
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'payment_method_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method payment_methods_partial_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `payment_methods_partial_update`")  # noqa: E501
        # verify the required parameter 'payment_method_id' is set
        if ('payment_method_id' not in params or
                params['payment_method_id'] is None):
            raise ValueError("Missing the required parameter `payment_method_id` when calling `payment_methods_partial_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'payment_method_id' in params:
            path_params['payment_method_id'] = params['payment_method_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/payment_methods/{payment_method_id}/', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaymentMethod',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def payment_methods_read(self, payment_method_id, **kwargs):  # noqa: E501
        """payment_methods_read  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_read(payment_method_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str payment_method_id: A UUID string identifying this payment method. (required)
        :return: PaymentMethod
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.payment_methods_read_with_http_info(payment_method_id, **kwargs)  # noqa: E501
        else:
            (data) = self.payment_methods_read_with_http_info(payment_method_id, **kwargs)  # noqa: E501
            return data

    def payment_methods_read_with_http_info(self, payment_method_id, **kwargs):  # noqa: E501
        """payment_methods_read  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_read_with_http_info(payment_method_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str payment_method_id: A UUID string identifying this payment method. (required)
        :return: PaymentMethod
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['payment_method_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method payment_methods_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'payment_method_id' is set
        if ('payment_method_id' not in params or
                params['payment_method_id'] is None):
            raise ValueError("Missing the required parameter `payment_method_id` when calling `payment_methods_read`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'payment_method_id' in params:
            path_params['payment_method_id'] = params['payment_method_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/payment_methods/{payment_method_id}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaymentMethod',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def payment_methods_update(self, body, payment_method_id, **kwargs):  # noqa: E501
        """payment_methods_update  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_update(body, payment_method_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PaymentMethod body: (required)
        :param str payment_method_id: A UUID string identifying this payment method. (required)
        :return: PaymentMethod
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.payment_methods_update_with_http_info(body, payment_method_id, **kwargs)  # noqa: E501
        else:
            (data) = self.payment_methods_update_with_http_info(body, payment_method_id, **kwargs)  # noqa: E501
            return data

    def payment_methods_update_with_http_info(self, body, payment_method_id, **kwargs):  # noqa: E501
        """payment_methods_update  # noqa: E501

        API endpoint that allow payment method to be viewed or edited  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.payment_methods_update_with_http_info(body, payment_method_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PaymentMethod body: (required)
        :param str payment_method_id: A UUID string identifying this payment method. (required)
        :return: PaymentMethod
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'payment_method_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method payment_methods_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `payment_methods_update`")  # noqa: E501
        # verify the required parameter 'payment_method_id' is set
        if ('payment_method_id' not in params or
                params['payment_method_id'] is None):
            raise ValueError("Missing the required parameter `payment_method_id` when calling `payment_methods_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'payment_method_id' in params:
            path_params['payment_method_id'] = params['payment_method_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/payment_methods/{payment_method_id}/', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaymentMethod',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Transaction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'transaction_id': 'str',
        'external_key': 'str',
        'payment_external_key': 'str',
        'amount': 'str',
        'currency': 'str',
        'processed_amount': 'str',
        'processed_currency': 'str',
        'type': 'str',
        'status': 'str',
        'gateway_error_code': 'str',
        'gateway_error_message': 'str',
        'refference_id': 'str',
        'plugin_properties': 'object',
        'effective_at': 'datetime',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'deleted_at': 'datetime',
        'account': 'str',
        'payment': 'str'
    }

    attribute_map = {
        'transaction_id': 'transaction_id',
        'external_key': 'external_key',
        'payment_external_key': 'payment_external_key',
        'amount': 'amount',
        'currency': 'currency',
        'processed_amount': 'processed_amount',
        'processed_currency': 'processed_currency',
        'type': 'type',
        'status': 'status',
        'gateway_error_code': 'gateway_error_code',
        'gateway_error_message': 'gateway_error_message',
        'refference_id': 'refference_id',
        'plugin_properties': 'plugin_properties',
        'effective_at': 'effective_at',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'deleted_at': 'deleted_at',
        'account': 'account',
        'payment': 'payment'
    }

    def __init__(self, transaction_id=None, external_key=None, payment_external_key=None, amount=None, currency=None, processed_amount=None, processed_currency=None, type=None, status=None, gateway_error_code=None, gateway_error_message=None, refference_id=None, plugin_properties=None, effective_at=None, created_at=None, updated_at=None, deleted_at=None, account=None, payment=None):  # noqa: E501
        """Transaction - a model defined in Swagger"""  # noqa: E501
        self._transaction_id = None
        self._external_key = None
        self._payment_external_key = None
        self._amount = None
        self._currency = None
        self._processed_amount = None
        self._processed_currency = None
        self._type = None
        self._status = None
        self._gateway_error_code = None
        self._gateway_error_message = None
        self._refference_id = None
        self._plugin_properties = None
        self._effective_at = None
        self._created_at = None
        self._updated_at = None
        self._deleted_at = None
        self._account = None
        self._payment = None
        self.discriminator = None
        if transaction_id is not None:
            self.transaction_id = transaction_id
        self.external_key = external_key
        if payment_external_key is not None:
            self.payment_external_key = payment_external_key
        if amount is not None:
            self.amount = amount
        if currency is not None:
            self.currency = currency
        if processed_amount is not None:
            self.processed_amount = processed_amount
        if processed_currency is not None:
            self.processed_currency = processed_currency
        self.type = type
        self.status = status
        if gateway_error_code is not None:
            self.gateway_error_code = gateway_error_code
        if gateway_error_message is not None:
            self.gateway_error_message = gateway_error_message
        if refference_id is not None:
            self.refference_id = refference_id
        if plugin_properties is not None:
            self.plugin_properties = plugin_properties
        if effective_at is not None:
            self.effective_at = effective_at
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if deleted_at is not None:
            self.deleted_at = deleted_at
        self.account = account
        self.payment = payment

    @property
    def transaction_id(self):
        """Gets the transaction_id of this Transaction.  # noqa: E501


        :return: The transaction_id of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this Transaction.


        :param transaction_id: The transaction_id of this Transaction.  # noqa: E501
        :type: str
        """

        self._transaction_id = transaction_id

    @property
    def external_key(self):
        """Gets the external_key of this Transaction.  # noqa: E501


        :return: The external_key of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """Sets the external_key of this Transaction.


        :param external_key: The external_key of this Transaction.  # noqa: E501
        :type: str
        """
        if external_key is None:
            raise ValueError("Invalid value for `external_key`, must not be `None`")  # noqa: E501

        self._external_key = external_key

    @property
    def payment_external_key(self):
        """Gets the payment_external_key of this Transaction.  # noqa: E501


        :return: The payment_external_key of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._payment_external_key

    @payment_external_key.setter
    def payment_external_key(self, payment_external_key):
        """Sets the payment_external_key of this Transaction.


        :param payment_external_key: The payment_external_key of this Transaction.  # noqa: E501
        :type: str
        """

        self._payment_external_key = payment_external_key

    @property
    def amount(self):
        """Gets the amount of this Transaction.  # noqa: E501


        :return: The amount of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Transaction.


        :param amount: The amount of this Transaction.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this Transaction.  # noqa: E501


        :return: The currency of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Transaction.


        :param currency: The currency of this Transaction.  # noqa: E501
        :type: str
        """
        allowed_values = ["USD", "AED"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def processed_amount(self):
        """Gets the processed_amount of this Transaction.  # noqa: E501


        :return: The processed_amount of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._processed_amount

    @processed_amount.setter
    def processed_amount(self, processed_amount):
        """Sets the processed_amount of this Transaction.


        :param processed_amount: The processed_amount of this Transaction.  # noqa: E501
        :type: str
        """

        self._processed_amount = processed_amount

    @property
    def processed_currency(self):
        """Gets the processed_currency of this Transaction.  # noqa: E501


        :return: The processed_currency of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._processed_currency

    @processed_currency.setter
    def processed_currency(self, processed_currency):
        """Sets the processed_currency of this Transaction.


        :param processed_currency: The processed_currency of this Transaction.  # noqa: E501
        :type: str
        """
        allowed_values = ["USD", "AED"]  # noqa: E501
        if processed_currency not in allowed_values:
            raise ValueError(
                "Invalid value for `processed_currency` ({0}), must be one of {1}"  # noqa: E501
                .format(processed_currency, allowed_values)
            )

        self._processed_currency = processed_currency

    @property
    def type(self):
        """Gets the type of this Transaction.  # noqa: E501


        :return: The type of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Transaction.


        :param type: The type of this Transaction.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def status(self):
        """Gets the status of this Transaction.  # noqa: E501


        :return: The status of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Transaction.


        :param status: The status of this Transaction.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def gateway_error_code(self):
        """Gets the gateway_error_code of this Transaction.  # noqa: E501


        :return: The gateway_error_code of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._gateway_error_code

    @gateway_error_code.setter
    def gateway_error_code(self, gateway_error_code):
        """Sets the gateway_error_code of this Transaction.


        :param gateway_error_code: The gateway_error_code of this Transaction.  # noqa: E501
        :type: str
        """

        self._gateway_error_code = gateway_error_code

    @property
    def gateway_error_message(self):
        """Gets the gateway_error_message of this Transaction.  # noqa: E501


        :return: The gateway_error_message of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._gateway_error_message

    @gateway_error_message.setter
    def gateway_error_message(self, gateway_error_message):
        """Sets the gateway_error_message of this Transaction.


        :param gateway_error_message: The gateway_error_message of this Transaction.  # noqa: E501
        :type: str
        """

        self._gateway_error_message = gateway_error_message

    @property
    def refference_id(self):
        """Gets the refference_id of this Transaction.  # noqa: E501


        :return: The refference_id of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._refference_id

    @refference_id.setter
    def refference_id(self, refference_id):
        """Sets the refference_id of this Transaction.


        :param refference_id: The refference_id of this Transaction.  # noqa: E501
        :type: str
        """

        self._refference_id = refference_id

    @property
    def plugin_properties(self):
        """Gets the plugin_properties of this Transaction.  # noqa: E501


        :return: The plugin_properties of this Transaction.  # noqa: E501
        :rtype: object
        """
        return self._plugin_properties

    @plugin_properties.setter
    def plugin_properties(self, plugin_properties):
        """Sets the plugin_properties of this Transaction.


        :param plugin_properties: The plugin_properties of this Transaction.  # noqa: E501
        :type: object
        """

        self._plugin_properties = plugin_properties

    @property
    def effective_at(self):
        """Gets the effective_at of this Transaction.  # noqa: E501


        :return: The effective_at of this Transaction.  # noqa: E501
        :rtype: datetime
        """
        return self._effective_at

    @effective_at.setter
    def effective_at(self, effective_at):
        """Sets the effective_at of this Transaction.


        :param effective_at: The effective_at of this Transaction.  # noqa: E501
        :type: datetime
        """

        self._effective_at = effective_at

    @property
    def created_at(self):
        """Gets the created_at of this Transaction.  # noqa: E501


        :return: The created_at of this Transaction.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Transaction.


        :param created_at: The created_at of this Transaction.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Transaction.  # noqa: E501


        :return: The updated_at of this Transaction.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Transaction.


        :param updated_at: The updated_at of this Transaction.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def deleted_at(self):
        """Gets the deleted_at of this Transaction.  # noqa: E501


        :return: The deleted_at of this Transaction.  # noqa: E501
        :rtype: datetime
        """
        return self._deleted_at

    @deleted_at.setter
    def deleted_at(self, deleted_at):
        """Sets the deleted_at of this Transaction.


        :param deleted_at: The deleted_at of this Transaction.  # noqa: E501
        :type: datetime
        """

        self._deleted_at = deleted_at

    @property
    def account(self):
        """Gets the account of this Transaction.  # noqa: E501


        :return: The account of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this Transaction.


        :param account: The account of this Transaction.  # noqa: E501
        :type: str
        """
        if account is None:
            raise ValueError("Invalid value for `account`, must not be `None`")  # noqa: E501

        self._account = account

    @property
    def payment(self):
        """Gets the payment of this Transaction.  # noqa: E501


        :return: The payment of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._payment

    @payment.setter
    def payment(self, payment):
        """Sets the payment of this Transaction.


        :param payment: The payment of this Transaction.  # noqa: E501
        :type: str
        """
        if payment is None:
            raise ValueError("Invalid value for `payment`, must not be `None`")  # noqa: E501

        self._payment = payment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Transaction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Transaction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from os import path

from setuptools import setup, find_packages  # noqa: H301

NAME = "spotii-billing-client"
VERSION = "1.0.2"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name=NAME,
    version=VERSION,
    description="Spotii Billing API",
    author_email="hello@nuclearo.com",
    url="",
    keywords=["Swagger", "Spotii Billing API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=long_description,
    long_description_content_type='text/markdown'
)
